{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "19f7262c-8624-40ff-bcac-db66f3848262",
   "metadata": {},
   "source": [
    "# Gust Loads\n",
    "\n",
    "In this section a gust loads analyses is going to be conducted. The  simulation set-up in <em>Loads Kernel</em> was already shown in detail in a previous notebook. Hence, the focus will be more in the results and post processing. In order to showcase the gust load analyses capabilities of <em>Loads Kernel</em> only one gust gradeint was simulated in the first example. This is justified with the large amount of time necessary to perform the simulation with all the different gust gradients. Nevertheless, the simulation with all the different gust gradients is shown and it is explained under the name 'Advanced Simulation' below."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "42e97fe9-1460-4f0e-9034-60d9ad3a32c9",
   "metadata": {},
   "source": [
    "## Simulation Set-up\n",
    "\n",
    "The simulation set-up is similar to the one done for the trim and maneuver load analyses with the only exception being the last part of the set-up regarding the self.trimcase and the self.simcase. To analyze gust loads, horizontal level flight (n<sub>Z</sub>=1) FL000 at trim conditions was selected. Again the mass configuration M3 was chosen. The gust gradient selected for this example is the gust gradient of 23 meters, which corresponds to the limit case. In the simulation a time step of 0.01 seconds and a simulation time of 2 seconds were utilized. The gust parameters were obtained in accordance with CS-25 {cite}`cs25`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "40b57f40-c219-4f7d-9541-b7a093456f4b",
   "metadata": {
    "tags": [
     "skip-execution"
    ]
   },
   "outputs": [],
   "source": [
    "class jcl:\n",
    "\n",
    "    def __init__(self):\n",
    "        \n",
    "        self.trimcase = [{'desc': 'CC.M3.OVCFL000.level', # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 1,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': 1.0,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': 0.0 / 180.0 * np.pi,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0 / 180.0 * np.pi,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0 ,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          }]\n",
    "        \n",
    "        self.simcase = [{'dt': 0.01,  # Time step size of the output in [s]\n",
    "                         # Final simulation time  in [s]\n",
    "                         't_final': 2.0,\n",
    "                         # True or False, enables 1-cosine gust according to CS-25\n",
    "                         'gust': True,\n",
    "                         # Gust gradient H (half gust length) in [m]\n",
    "                         'gust_gradient': 23.0,\n",
    "                         # Orientation of the gust in [deg], 0/360 = gust from bottom, 180 = gust from top,\n",
    "                         # 90 = gust from the right, 270 = gust from the left, arbitrary values possible\n",
    "                         # (rotation of gust direction vector about Nastran's x-axis pointing backwards)\n",
    "                         'gust_orientation': 0,\n",
    "                         # Gust parameters according to CS-25 to calculate the gust velocity\n",
    "                         # MD is the dive speed in Mach\n",
    "                         'gust_para': {'Z_mo': 8046.72, 'MLW': 11793.40, 'MTOW': 11883.98, 'MZFW': 10594.47, 'MD': 0.334,\n",
    "                                       'T1': 0.0},\n",
    "                         # Alternatively, give gust velocity / Vtas directly\n",
    "                         # 'WG_TAS': 0.1,\n",
    "                         # True or False, enables continuous turbulence excitation\n",
    "                         'turbulence': False,\n",
    "                         # True or False, calculates limit turbulence according to CS-25\n",
    "                         'limit_turbulence': False,\n",
    "                         # True or False, enables playback of control surface signals via efcs\n",
    "                         'cs_signal': False,\n",
    "                         # True or False, enables a generic controller e.g. to maintain p, q and r\n",
    "                         'controller': False,\n",
    "                         # True or False, enables a generic landing gear\n",
    "                         'landinggear': False,\n",
    "                         # True or False, enables calculation of rigid and elastic derivatives\n",
    "                         'derivatives': False,\n",
    "                         # True or False, enables flutter check with k, ke or pk method\n",
    "                         'flutter': False,\n",
    "                         }]"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "5f9cd38e-c690-4513-9654-4e7bc1424eea",
   "metadata": {},
   "source": [
    "In order to obtain the results the following 'launch.py' file is run. The results can be found in the folder 'DC-3_results'."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "29800512-fa3e-408d-b698-2c37a048fa55",
   "metadata": {
    "scrolled": true,
    "tags": [
     "skip-execution"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "INFO: This is the log for process 0.\n",
      "INFO: Starting Loads Kernel with job: jcl_dc3_gust_H23\n",
      "INFO: User carn_fr on schwalbe (Linux-4.18.0-513.24.1.el8_9.x86_64-x86_64-with-glibc2.28)\n",
      "INFO: pre:  True\n",
      "INFO: main: True\n",
      "INFO: post: True\n",
      "INFO: test: False\n",
      "INFO: --> Reading parameters from JCL.\n",
      "INFO: --> Starting preprocessing.\n",
      "INFO: Building structural model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/structure_only.bdf\n",
      "INFO: Found include(s):\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_FUS.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.GRID_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.RBE2_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/export_left-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.GRID_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.RBE2_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing//export_right-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.GRID_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.RBE2_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/export_left-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.GRID_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.RBE2_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/export_right-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.GRID_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.RBE2_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/export_vt.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_left-nacell.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_right-nacell.csv\n",
      "INFO: The structural model consists of 278 grid points (1668 DoFs) and 7 coordinate systems.\n",
      "INFO: Reading Monitoring Stations from MONPNTs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/export_monitoring-stations.csv\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 192 DOFs...\n",
      "INFO: Building atmo model...\n",
      "INFO: Building aero model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.CAERO1\n",
      "INFO: Constructing aero panels from CAERO cards\n",
      "INFO:  - from corner points and aero panels, constructing aerogrid\n",
      "INFO: Read W2GJ data from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/w2gj_list.DMI_merge\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AELIST\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Calculating steady AIC matrices (1056 panels, k=0.0) for 1 Mach number(s)...\n",
      "INFO: done in 0.38 [sec].\n",
      "INFO: Calculating unsteady AIC matrices (1056 panels, k=[0.001, 0.1, 0.3, 0.6, 1.0, 1.5, 2.0, 3.0] (Nastran Definition!))             for 1 Mach number(s)...\n",
      "INFO: done in 29.33 [sec].\n",
      "INFO: Performing rational function approximation (RFA) on AIC matrices with 4 poles...\n",
      "INFO: - solving B = A*x with least-squares method\n",
      "INFO: - root-mean-square error(s): \n",
      "INFO:   k = 0.001 , RMSE_real = 0.0005720125389303132, RMSE_imag = 8.148603817532326e-06\n",
      "INFO:   k = 0.1   , RMSE_real = 0.00041807481116542486, RMSE_imag = 0.00048220449848666787\n",
      "INFO:   k = 0.3   , RMSE_real = 0.0006588508335750756, RMSE_imag = 0.0003448677217333894\n",
      "INFO:   k = 0.6   , RMSE_real = 0.0004535145823103877, RMSE_imag = 0.0012483389774543253\n",
      "INFO:   k = 1.0   , RMSE_real = 0.0017925260984709345, RMSE_imag = 0.0007525162422984316\n",
      "INFO:   k = 1.5   , RMSE_real = 0.0016356640792206374, RMSE_imag = 0.0011109219821269012\n",
      "INFO:   k = 2.0   , RMSE_real = 0.0008890505196004791, RMSE_imag = 0.0027241199582818056\n",
      "INFO:   k = 3.0   , RMSE_real = 0.000227376445707805, RMSE_imag = 0.001601657886637573\n",
      "INFO: The aerodynamic model consists of 1056 panels and 5 control surfaces.\n",
      "INFO: Coupling aerogrid directly. Doing cleanup/thin out of strcgrid to avoid singularities                     (safety first!)\n",
      "INFO: The spline model consists of 272 grid points.\n",
      "INFO: Searching nearest neighbour of 1056 dependent nodes in 272 independent nodes...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 1668 DOFs...\n",
      "INFO: Building stiffness and mass model...\n",
      "INFO: Reading matrix KGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Reading matrix GM from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Read USET from OP2-file /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/uset.op2 ...\n",
      "Table  USET    , bytes =       6935 [         0 to       6936]\n",
      "INFO: Extracting bit positions from USET to determine DoFs\n",
      "INFO: Prepare stiffness matrices for independent and free DoFs (f-set)\n",
      "INFO: Mass configuration 1 of 1: M3 \n",
      "INFO: Reading matrix MGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_M3.mtx.h5\n",
      "INFO: Calculate center of gravity, mass and inertia (GRDPNT)...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Mass: 11883.983000000002\n",
      "INFO: CG at: [8.62280419e+00 5.43474355e-08 3.11704131e-01]\n",
      "INFO: Inertia: \n",
      "[[ 6.93201323e+04 -3.80956656e-04  1.17729353e+04]\n",
      " [-3.80956654e-04  1.40925492e+05 -1.74794555e-04]\n",
      " [ 1.17729353e+04 -1.74794555e-04  1.97104534e+05]]\n",
      "INFO: Prepare mass matrices for independent and free DoFs (f-set)\n",
      "INFO: Modal analysis for first 26 modes...\n",
      "INFO: Found 26 modes with the following frequencies [Hz]:\n",
      "INFO: [           nan            nan 1.05457802e-06 4.52538930e-06\n",
      " 1.45457362e-05 3.39333114e-05 3.13716140e+00 4.68251648e+00\n",
      " 7.20798842e+00 7.88159198e+00 8.33703334e+00 8.49130434e+00\n",
      " 9.88499185e+00 1.25695152e+01 1.53520000e+01 1.70224904e+01\n",
      " 1.71353125e+01 1.84415883e+01 2.53323405e+01 2.53529787e+01\n",
      " 2.68433853e+01 2.81886244e+01 3.20724571e+01 3.24562324e+01\n",
      " 3.51081211e+01 3.52877859e+01]\n",
      "INFO: From these 26 modes, the following 20 modes are selected: [ 7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26]\n",
      "INFO: Working on f-set\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Working on h-set\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: --> Saving model data.\n",
      "INFO: --> Done in 0:00:34 [h:mm:ss].\n",
      "INFO: --> Starting Main in sequential mode for 1 trimcase(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 1\n",
      "INFO: (case 1 of 1)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1730\n",
      "INFO: Running time simulation for 2.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: --> Saving monstation(s).\n",
      "INFO: --> Saving dyn2stat.\n",
      "INFO: --> Done in 0:00:37 [h:mm:ss].\n",
      "INFO: --> Opening response(s).\n",
      "INFO: --> Loading monstations(s).\n",
      "INFO: --> Loading dyn2stat.\n",
      "INFO: --> Drawing some standard plots.\n",
      "INFO: start potato-plotting...\n",
      "INFO: start plotting cutting forces along wing...\n",
      "INFO: plots saved as ./DC3_results/monstations_jcl_dc3_gust_H23.pdf\n",
      "INFO: start plotting cutting forces over time ...\n",
      "INFO: plots saved as ./DC3_results/monstations_time_jcl_dc3_gust_H23.pdf\n",
      "INFO: --> Saving auxiliary output data.\n",
      "INFO: writing critical trimcases cases to: ./DC3_results/crit_trimcases_jcl_dc3_gust_H23.csv\n",
      "INFO: saving critical nodal loads as Nastarn cards...\n",
      "INFO: Loads Kernel finished.\n",
      "INFO: \n",
      "INFO:        (  )\n",
      "INFO:       (    )\n",
      "INFO: \n",
      "INFO:               (   )\n",
      "INFO:              (     )\n",
      "INFO: \n",
      "INFO:          _|_\n",
      "INFO:  ---------O---------\n",
      "INFO: \n",
      "INFO: \n"
     ]
    }
   ],
   "source": [
    "from loadskernel import program_flow\n",
    "\n",
    "# Here you launch the Loads Kernel with your job\n",
    "k = program_flow.Kernel('jcl_dc3_gust_H23', pre=True, main=True, post=True, test=False,\n",
    "                        path_input='./DC3_model/JCLs',\n",
    "                        path_output='./DC3_results')\n",
    "k.run()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3b8ae030-a789-4788-8781-5209a62b799f",
   "metadata": {},
   "source": [
    "## Results\n",
    "\n",
    "As it was done for the analyses of the maneuver loads, two-dimensional load envelopes were constructed. Again, the M<sub>x</sub>/M<sub>y</sub> load envelope is going to be interpreted. In the following figure the torsional and bending moments envelope is shown for the left wing root. First, one can see that the envelope shape resembles a certain direct correlation between the bending and torsional moments. Second, one can see that the highest negative bending moments  M<sub>x</sub> and highest negative torsional moments M<sub>y</sub> are reached by the gust load at the time instants between 0.36 and 0.48 seconds. The highest positive bending moments  M<sub>x</sub> and the highest positive torsional moments M<sub>y</sub> are reached by the gust load at the time instants close to 1 second.\n",
    "\n",
    "<img src=\"./images/MyMx_gust.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> and torsional moment M<sub>y</sub> at the wing root.*\n",
    "\n",
    "Once again, one-dimensional envelopes along the wing span were studied to provide insights into the evolution of section loads across the wing. The next figure illustrates the envelope of the bending moment M<sub>x</sub> along the wingspan. The highest positive bending moment arise from the gust load at the time instants between 0.50 and 0.54 seconds. On the other hand, the highest negative bending moment arises from the gust load at the time instants between 0.87 and 0.88 seconds.\n",
    "\n",
    "<img src=\"./images/Mx_y_gust.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> along the wing span.*\n",
    "\n",
    "Furthermore, in order to have a deeper understanding of the gust loads, the forces and moments of the different gust profiles were plotted over time. Observing, the bending moments M<sub>x</sub> over time for the gust gradients H=23m at the wing root (figure below), it can be seen that the magnitude of the positive peak is very close to the negative peak, which was unexpected. The explanation for this comes further on in the Advanced Simulation section.\n",
    "\n",
    "<img src=\"./images/Mx_time.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> over time at the wing root.*"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "25ab2e5a-1041-41e1-aad8-a5fb5e20f005",
   "metadata": {},
   "source": [
    "## Advanced Simulation\n",
    "\n",
    "In this section a more complete gust load analyses is presented. In the DC-3 case, for the gust load analyses, a gust gradient of 9, 16, 23, 30, 37, 51, 65, 79, 93 and 107 meters were selected in accordance with CS-25.341 {cite}`cs25`. In every simulation a time step of 0.01 seconds and a simulation time of 3 seconds were utilized. The gust parameters were obtained in accordance with CS-25 too.\n",
    "\n",
    "To run the simulation the 'launch.py' file is run. The results can be fouund in the folder 'DC-3_results'."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "21457773-07c0-4c6a-9ff2-c521d26d4769",
   "metadata": {
    "tags": [
     "skip-execution"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "INFO: This is the log for process 0.\n",
      "INFO: Starting Loads Kernel with job: jcl_dc3_gust\n",
      "INFO: User carn_fr on schwalbe (Linux-4.18.0-513.24.1.el8_9.x86_64-x86_64-with-glibc2.28)\n",
      "INFO: pre:  True\n",
      "INFO: main: True\n",
      "INFO: post: True\n",
      "INFO: test: False\n",
      "INFO: --> Reading parameters from JCL.\n",
      "INFO: --> Starting preprocessing.\n",
      "INFO: Building structural model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/structure_only.bdf\n",
      "INFO: Found include(s):\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_FUS.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.GRID_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.RBE2_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/export_left-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.GRID_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.RBE2_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing//export_right-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.GRID_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.RBE2_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/export_left-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.GRID_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.RBE2_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/export_right-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.GRID_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.RBE2_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/export_vt.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_left-nacell.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_right-nacell.csv\n",
      "INFO: The structural model consists of 278 grid points (1668 DoFs) and 7 coordinate systems.\n",
      "INFO: Reading Monitoring Stations from MONPNTs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/export_monitoring-stations.csv\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 192 DOFs...\n",
      "INFO: Building atmo model...\n",
      "INFO: Building aero model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.CAERO1\n",
      "INFO: Constructing aero panels from CAERO cards\n",
      "INFO:  - from corner points and aero panels, constructing aerogrid\n",
      "INFO: Read W2GJ data from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/w2gj_list.DMI_merge\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AELIST\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Calculating steady AIC matrices (1056 panels, k=0.0) for 1 Mach number(s)...\n",
      "INFO: done in 0.30 [sec].\n",
      "INFO: Calculating unsteady AIC matrices (1056 panels, k=[0.001, 0.1, 0.3, 0.6, 1.0, 1.5, 2.0, 3.0] (Nastran Definition!))             for 1 Mach number(s)...\n",
      "INFO: done in 29.92 [sec].\n",
      "INFO: Performing rational function approximation (RFA) on AIC matrices with 4 poles...\n",
      "INFO: - solving B = A*x with least-squares method\n",
      "INFO: - root-mean-square error(s): \n",
      "INFO:   k = 0.001 , RMSE_real = 0.0005720125389303132, RMSE_imag = 8.148603817532326e-06\n",
      "INFO:   k = 0.1   , RMSE_real = 0.00041807481116542486, RMSE_imag = 0.00048220449848666787\n",
      "INFO:   k = 0.3   , RMSE_real = 0.0006588508335750756, RMSE_imag = 0.0003448677217333894\n",
      "INFO:   k = 0.6   , RMSE_real = 0.0004535145823103877, RMSE_imag = 0.0012483389774543253\n",
      "INFO:   k = 1.0   , RMSE_real = 0.0017925260984709345, RMSE_imag = 0.0007525162422984316\n",
      "INFO:   k = 1.5   , RMSE_real = 0.0016356640792206374, RMSE_imag = 0.0011109219821269012\n",
      "INFO:   k = 2.0   , RMSE_real = 0.0008890505196004791, RMSE_imag = 0.0027241199582818056\n",
      "INFO:   k = 3.0   , RMSE_real = 0.000227376445707805, RMSE_imag = 0.001601657886637573\n",
      "INFO: The aerodynamic model consists of 1056 panels and 5 control surfaces.\n",
      "INFO: Coupling aerogrid directly. Doing cleanup/thin out of strcgrid to avoid singularities                     (safety first!)\n",
      "INFO: The spline model consists of 272 grid points.\n",
      "INFO: Searching nearest neighbour of 1056 dependent nodes in 272 independent nodes...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 1668 DOFs...\n",
      "INFO: Building stiffness and mass model...\n",
      "INFO: Reading matrix KGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Reading matrix GM from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Read USET from OP2-file /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/uset.op2 ...\n",
      "Table  USET    , bytes =       6935 [         0 to       6936]\n",
      "INFO: Extracting bit positions from USET to determine DoFs\n",
      "INFO: Prepare stiffness matrices for independent and free DoFs (f-set)\n",
      "INFO: Mass configuration 1 of 1: M3 \n",
      "INFO: Reading matrix MGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_M3.mtx.h5\n",
      "INFO: Calculate center of gravity, mass and inertia (GRDPNT)...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Mass: 11883.983000000002\n",
      "INFO: CG at: [8.62280419e+00 5.43474355e-08 3.11704131e-01]\n",
      "INFO: Inertia: \n",
      "[[ 6.93201323e+04 -3.80956656e-04  1.17729353e+04]\n",
      " [-3.80956654e-04  1.40925492e+05 -1.74794555e-04]\n",
      " [ 1.17729353e+04 -1.74794555e-04  1.97104534e+05]]\n",
      "INFO: Prepare mass matrices for independent and free DoFs (f-set)\n",
      "INFO: Modal analysis for first 26 modes...\n",
      "INFO: Found 26 modes with the following frequencies [Hz]:\n",
      "INFO: [           nan            nan 1.05457802e-06 4.52538930e-06\n",
      " 1.45457362e-05 3.39333114e-05 3.13716140e+00 4.68251648e+00\n",
      " 7.20798842e+00 7.88159198e+00 8.33703334e+00 8.49130434e+00\n",
      " 9.88499185e+00 1.25695152e+01 1.53520000e+01 1.70224905e+01\n",
      " 1.71353125e+01 1.84415883e+01 2.53323405e+01 2.53529788e+01\n",
      " 2.68433851e+01 2.81886246e+01 3.20724571e+01 3.24562324e+01\n",
      " 3.51081211e+01 3.52877859e+01]\n",
      "INFO: From these 26 modes, the following 20 modes are selected: [ 7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26]\n",
      "INFO: Working on f-set\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Working on h-set\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: --> Saving model data.\n",
      "INFO: --> Done in 0:00:34 [h:mm:ss].\n",
      "INFO: --> Starting Main in sequential mode for 10 trimcase(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 1\n",
      "INFO: (case 1 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1479\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 2\n",
      "INFO: (case 2 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1628\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 3\n",
      "INFO: (case 3 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1730\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 4\n",
      "INFO: (case 4 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1808\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 5\n",
      "INFO: (case 5 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1872\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 6\n",
      "INFO: (case 6 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.1975\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 7\n",
      "INFO: (case 7 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.2057\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 8\n",
      "INFO: (case 8 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.2125\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 9\n",
      "INFO: (case 9 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.2183\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 10\n",
      "INFO: (case 10 of 10)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 26 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: Adding 1056 x 4 unsteady lag states to the system\n",
      "INFO: Init model equations of type \"Unsteady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: CS25_Uds is set up with flight profile alleviation factor Fg = 0.9164764669699965\n",
      "INFO: Gust set up with initial Vtas = 70.0000, t1 = 0.0, WG_tas = 0.2235\n",
      "INFO: Running time simulation for 3.0 sec...\n",
      "INFO: Simulation finished. Running (again) with full outputs at selected time steps...\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: reducing dyn2stat data...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: --> Saving monstation(s).\n",
      "INFO: --> Saving dyn2stat.\n",
      "INFO: --> Done in 0:09:13 [h:mm:ss].\n",
      "INFO: --> Opening response(s).\n",
      "INFO: --> Loading monstations(s).\n",
      "INFO: --> Loading dyn2stat.\n",
      "INFO: --> Drawing some standard plots.\n",
      "INFO: start potato-plotting...\n",
      "INFO: start plotting cutting forces along wing...\n",
      "INFO: plots saved as ./DC3_results/monstations_jcl_dc3_gust.pdf\n",
      "INFO: start plotting cutting forces over time ...\n",
      "INFO: plots saved as ./DC3_results/monstations_time_jcl_dc3_gust.pdf\n",
      "INFO: --> Saving auxiliary output data.\n",
      "INFO: writing critical trimcases cases to: ./DC3_results/crit_trimcases_jcl_dc3_gust.csv\n",
      "INFO: saving critical nodal loads as Nastarn cards...\n",
      "INFO: Loads Kernel finished.\n",
      "INFO: \n",
      "INFO:        (  )\n",
      "INFO:       (    )\n",
      "INFO: \n",
      "INFO:               (   )\n",
      "INFO:              (     )\n",
      "INFO: \n",
      "INFO:          _|_\n",
      "INFO:  ---------O---------\n",
      "INFO: \n",
      "INFO: \n"
     ]
    }
   ],
   "source": [
    "from loadskernel import program_flow\n",
    "\n",
    "# Here you launch the Loads Kernel with your job\n",
    "k = program_flow.Kernel('jcl_dc3_gust', pre=True, main=True, post=True, test=False,\n",
    "                        path_input='./DC3_model/JCLs',\n",
    "                        path_output='./DC3_results')\n",
    "k.run()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e17d6274-c0ef-4d3a-b164-23075284f454",
   "metadata": {},
   "source": [
    "## Results Advanced Simulation\n",
    "\n",
    "To study the gust loads the (1-cos) Discrete Gust Model was implemented in <em>Loads Kernel</em>. The gust analyses was performed in the same conditions as the maneuvers at True Airspeed (TAS) of 70 m/s and Flight Level FL000 at trim conditions. In accordance to CS-25.341 {cite}`cs25` the gust profiles at sea level were obtained, and are exposed in the next figure.\n",
    "\n",
    "<img src=\"./images/gust_shapes.png\" width=\"350\" alt=\"DC3\">\n",
    "\n",
    "*Gust shapes at sea-level according to CS-25.*\n",
    "\n",
    "To have a more detailed understanding of the gust shapes, the gust gradients and their corresponding peak velocities are listed in the following table. Concerning the orientation of the gust, only vertical gusts are going to be studied.\n",
    "\n",
    "<img src=\"./images/gust_table.png\" width=\"500\" alt=\"DC3\">\n",
    "\n",
    "*Gust gradients and corresponding peak velocities.*\n",
    "\n",
    "As it was done for the analyses of the maneuver loads, two-dimensional load envelopes were constructed. Again, the M<sub>x</sub>/M<sub>y</sub> load envelope is going to be interpreted. In the figure below the torsional and bending moments envelope is shown for the left wing root. First, one can see that the envelope shape resembles a certain direct correlation between the bending and torsional moments. Second, one can see that the highest negative bending moments M<sub>x</sub> are reached by the gust loads with gust gradients H=16, 23, 30 and 37 m, while the highest negative torsional moments M<sub>y</sub> are reached by the gust loads with gust gradient H=9 m. The highest positive bending moments M<sub>x</sub> are reached by the gust load with gust gradient H=51 m, this gust load corresponds to the smallest negative torsional moments M<sub>y</sub>. Third, both maneuver and gust envelopes are very close to each other, which is an indicator for well-selected load cases which harmonize with each other in the sense that there are no extreme loads cases which dominate the design. That can be concluded comparing the figure below with the analogous figure obtained in the manuever load analyses.\n",
    "\n",
    "<img src=\"./images/MxMy_gust_adv.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> and torsional moment M<sub>y</sub> at the wing root.*\n",
    "\n",
    "Once again, one-dimensional envelopes along the wing span were studied to provide insights into the evolution of section loads across the wing. The following figure illustrates the envelope of the bending moment M<sub>x</sub> along the wing span. Comparing the results between the maneuver and gust loads, one can see that magnitude of the values is the same. Due to the fact that the results are symmetric, the conclusions drawn from the right wing (y>0) are valid for the left wing. In the inboard part of the right wing, the highest positive bending moment arise from the gust load with gust gradient H=23 m. For the outboard section the highest values correspond to the gust load with gust gradient H=16 m, except for the last three monitoring stations closer to the tip. For the monitoring station located at the tip the\n",
    "highest value is for the gust load with gust gradient H=51 m and for the other two is for the gust load with gust gradient H=9 m. On the other hand, the highest negative bending moment arises from the gust load with gust gradient H=51 m for the entire wing span, except for the tip for which the highest value is for the gust load with gust gradient H=37 m.\n",
    "\n",
    "<img src=\"./images/Mx_y_gust_adv.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> along the wing span.*\n",
    "\n",
    "Furthermore, in order to have a deeper understanding of the gust loads, the forces and moments of the different gust profiles were plotted over time. The time step chosen was 0.01 seconds which is a step size with a good balance between accuracy and computational efficiency. It maintains acceptable results and at the same time is large enough to not be very computationally demanding. The interval time selected\n",
    "for the gust analyses was 3 seconds, which is more than enough to capture the several peaks for each gust profile. Observing, the bending moments M<sub>x</sub> over time for the different gust gradients at the wing root (figure below), it can be seen that the magnitude of the positive peaks is very close to the negative peaks, which was unexpected. Moreover, the highest positive peak is reached for a gust gradient of H=23 m. Empirical data collected in the 1940s shows that the highest gust excitations on legacy aircraft occur at a gradient corresponding to 12.5 spatial chord lengths on average. Being the mean aerodynamic chord c=3.508 m, the highest positive peak should have been reached around a gust gradient of H=44 m, almost the value obtained.\n",
    "\n",
    "<img src=\"./images/Mx_t_gust_adv.png\" width=\"450\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> along the wing span.*\n",
    "\n",
    "It was tought that the source was possible a coupling between the gusts and one of the longitudinal flight mechanics modes, namely the short period. One way to eliminate this coupling is to decreased the distance between the aerodynamic center and the center of gravity, so the static margin. The aircraft model has a very high static margin in the M3 mass configuration, which was reduced to approximately 10%. This resulted in the magnitude of the positive and negative peaks of the moments/forces over time plots to change so that the magnitude of these peaks was then much different. On top of that, the highest peak was then arising from a gust with a gust gradient between H=37 m\n",
    "and H=51 m. This means the empirical predicted gust gradient value of H=44 m falls in this range. This goes to show that the unexpected gust load results obtained are justified by this gust and short period coupling that happens for gust profiles with small gust gradients.\n",
    "\n",
    "For additional information about the meanuver load results please refer to {cite}`Carvalho2024`."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.13"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
